@ECHO OFF

REM This batch file compiles a Win32 resource containing the application icon
REM and then compiles Digger to assume the required resource files are linked in
REM as managed resources. Delphi for .NET will not link these managed resources in
REM but we get around that by using creative round tripping. The generated executable is
REM disassembled to IL, then reassembled in conjunction with another IL file that 
REM contains the directives to link in the managed resources. The result is a
REM fully self-contained .NET executable with managed resources (Digger.exe)

CLS

ECHO *** Deleting old executable (if present) ***
ECHO.

IF EXIST Digger.exe DEL Digger.exe

ECHO *** Compiling the icon into a resource file ***
ECHO.

brcc32 Digger.rc
IF ERRORLEVEL 1 GOTO BadExit

ECHO.
ECHO *** Deleting command-line compiler config file (if present) ***

IF EXIST Digger.cfg DEL Digger.cfg

ECHO.
ECHO *** Compiling Digger to use linked managed resources ***
ECHO.

dccil -B -DLINK_RESOURCES Digger.dpr
IF ERRORLEVEL 1 GOTO BadExit

ECHO.
ECHO *** Disassembling Digger ***
ECHO.

ildasm Digger.exe /linenum /nobar /out:Digger.il
IF ERRORLEVEL 1 GOTO BadExit

ECHO.
ECHO *** Reassembling Digger with linked resources ***

ilasm Digger DiggerResources /quiet /nologo /debug /resource:Digger.res
IF ERRORLEVEL 1 GOTO BadExit

ECHO.
ECHO *** Verifying generated executable ***

peverify Digger.exe

ECHO.
ECHO *** Showing generated executable details ***
ECHO.

DIR Digger.exe

ECHO.
ECHO *** Launching Digger ***

start Digger.exe

GOTO Exit

:BadExit

ECHO.
ECHO An error occurred during the build process
PAUSE
GOTO Exit

:Exit